@@ -1,6 +1,6 @@
 /**
  *	This file is part of devilspie2
- *	Copyright (C) 2001 Havoc Pennington, 2011-2012 Andreas Rönnquist
+ *	Copyright (C) 2001 Havoc Pennington, 2011-2014 Andreas Rönnquist
  *
  *	devilspie2 is free software: you can redistribute it and/or
  *	modify it under the terms of the GNU General Public License as published
@@ -25,21 +25,32 @@
  */
 Atom my_wnck_atom_get(const char *atom_name);
 
-void my_wnck_change_state(Screen *screen, Window xwindow, gboolean add, Atom state1, Atom state2);
+void devilspie2_change_state(Screen *screen,
+									Window xwindow,
+									gboolean add,
+									Atom state1,
+									Atom state2);
 
-Screen* my_wnck_window_get_xscreen(WnckWindow *window);
+Screen* devilspie2_window_get_xscreen(Window xid);
 
-void my_wnck_error_trap_push();
-int my_wnck_error_trap_pop();
+void devilspie2_error_trap_push();
+int devilspie2_error_trap_pop();
 
-gboolean decorate_window(WnckWindow *window);
-gboolean undecorate_window(WnckWindow *window);
+gboolean decorate_window(Window xid);
+gboolean undecorate_window(Window xid);
 
 char* my_wnck_get_string_property_latin1 (Window xwindow, Atom atom);
 
-gboolean my_wnck_get_cardinal_list(Window xwindow, Atom atom, gulong **cardinals, int *len);
-glong my_wnck_get_cardinal(Window xwindow, Atom atom);
+gboolean my_wnck_get_cardinal_list(Window xwindow,
+												Atom atom,
+												gulong **cardinals,
+												int *len);
 
-int my_wnck_get_viewport_start(WnckWindow *win);
+int devilspie2_get_viewport_start(Window xwindow);
+
+void my_window_set_window_type(Window xid, gchar *window_type);
+void my_window_set_opacity(Window xid, double value);
+
+void set_window_geometry(WnckWindow *window, int x, int y, int w, int h);
 
 #endif /*__HEADER_XUTILS_*/
